@@ -115,11 +115,16 @@ class WBGenericDBManager(AbstractWBDBManager):
                     gene_name_id_map[row[1]] = "WBGene" + row[0]
             return gene_name_id_map
 
-    def get_curated_transgenes(self, exclude_id_used_as_name: bool = False):
+    def get_curated_transgenes(self, exclude_id_used_as_name: bool = False, exclude_invalid: bool = True):
         with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
+            invalid_ids = set()
+            if exclude_invalid:
+                curs.execute("select joinkey from trp_objpap_falsepos where trp_objpap_falsepos = 'Fail'")
+                invalid_ids = set([row[0] for row in curs.fetchall()])
             curs.execute("SELECT * FROM trp_publicname")
             rows = curs.fetchall()
-            return [row[1] for row in rows]
+            return sorted(list(set([row[1] for row in rows if (not exclude_invalid or row[0] not in invalid_ids) and
+                                    (not exclude_id_used_as_name or not row[1].startswith("WBTransgene"))])))
 
     def get_transgene_name_id_map(self):
         with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
@@ -237,18 +242,3 @@ class WBGenericDBManager(AbstractWBDBManager):
             else:
                 return []
 
-    def get_paper_ids_processed_antibody(self):
-        with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
-            curs.execute("SELECT cur_paper FROM cur_strdata where cur_datatype = 'antibody'")
-            return [row[0] for row in curs.fetchall()]
-
-    def get_antibody_str_values(self, from_date):
-        with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
-            curs.execute("SELECT cur_paper, cur_strdata FROM cur_strdata where cur_datatype = 'antibody' "
-                         "and cur_timestamp >= %(from_date)s", {'from_date': from_date})
-            return [(row[0], row[1]) for row in curs.fetchall()]
-
-    def save_antybody_str_values(self, paper_id, str_values):
-        with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
-            curs.execute("INSERT INTO cur_strdata (cur_paper, cur_datatype, cur_strdata) "
-                         "VALUES (%s, 'antibody', %s)", (paper_id, str_values))
